==> google-cloud-pubsublite-1.0.1.tar.gz: google-cloud-pubsublite-1.0.1/tests/unit/pubsublite/cloudpubsub/internal/publisher_impl_test.py <==
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from asynctest.mock import MagicMock
import pytest

from google.cloud.pubsublite.cloudpubsub.internal.publisher_impl import (
    SinglePublisherImpl,
)
from google.cloud.pubsublite.cloudpubsub.internal.single_publisher import (
    AsyncSinglePublisher,
    SinglePublisher,
)


@pytest.fixture()
def async_publisher():
    publisher = MagicMock(spec=AsyncSinglePublisher)
    publisher.__aenter__.return_value = publisher
    return publisher


@pytest.fixture()
def publisher(async_publisher):
    return SinglePublisherImpl(async_publisher)


def test_proxies_to_async(async_publisher, publisher: SinglePublisher):
    with publisher:
        async_publisher.__aenter__.assert_called_once()
        publisher.publish(data=b"abc", ordering_key="zyx", xyz="xyz").result()
        async_publisher.publish.assert_called_once_with(
            data=b"abc", ordering_key="zyx", xyz="xyz"
        )
    async_publisher.__aexit__.assert_called_once()

==> google-cloud-pubsublite-1.8.1.tar.gz: google-cloud-pubsublite-1.8.1/tests/unit/pubsublite/cloudpubsub/internal/publisher_impl_test.py <==
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from unittest.mock import MagicMock
import pytest

from google.cloud.pubsublite.cloudpubsub.internal.publisher_impl import (
    SinglePublisherImpl,
)
from google.cloud.pubsublite.cloudpubsub.internal.single_publisher import (
    AsyncSinglePublisher,
    SinglePublisher,
)


@pytest.fixture()
def async_publisher():
    publisher = MagicMock(spec=AsyncSinglePublisher)
    publisher.__aenter__.return_value = publisher
    return publisher


@pytest.fixture()
def publisher(async_publisher):
    return SinglePublisherImpl(async_publisher)


def test_proxies_to_async(async_publisher, publisher: SinglePublisher):
    with publisher:
        async_publisher.__aenter__.assert_called_once()
        publisher.publish(data=b"abc", ordering_key="zyx", xyz="xyz").result()
        async_publisher.publish.assert_called_once_with(
            data=b"abc", ordering_key="zyx", xyz="xyz"
        )
    async_publisher.__aexit__.assert_called_once()
